==> apache-camel-3.0.0-src.zip: apache-camel-3.0.0/components/camel-jira/src/main/java/org/apache/camel/component/jira/JiraComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jira;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.Metadata;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;

/**
 * Represents the component that manages {@link JiraEndpoint}.
 */
@Component("jira")
public class JiraComponent extends DefaultComponent {

    @Metadata(label = "advanced")
    private JiraConfiguration configuration;

    public JiraComponent() {
        this(null);
    }

    public JiraComponent(CamelContext context) {
        super(context);
        configuration = new JiraConfiguration();
        registerExtension(new JiraVerifierExtension());
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        // override configuration from route parameters
        setProperties(configuration, parameters);

        JiraEndpoint endpoint = new JiraEndpoint(uri, this, configuration);
        endpoint.setType(getCamelContext().getTypeConverter().convertTo(JiraType.class, remaining));
        return endpoint;
    }

    /**
     * The JiraConfiguration parameters
     */
    public JiraConfiguration getConfiguration() {
        return configuration;
    }

    public void setConfiguration(JiraConfiguration configuration) {
        this.configuration = configuration;
    }

}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/components/camel-jira/src/main/java/org/apache/camel/component/jira/JiraComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jira;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.Metadata;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.HealthCheckComponent;

@Component("jira")
public class JiraComponent extends HealthCheckComponent {

    @Metadata(label = "advanced")
    private JiraConfiguration configuration = new JiraConfiguration();

    public JiraComponent() {
        this(null);
    }

    public JiraComponent(CamelContext context) {
        super(context);
        registerExtension(new JiraVerifierExtension());
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        JiraConfiguration config = configuration != null ? configuration.copy() : new JiraConfiguration();

        JiraEndpoint endpoint = new JiraEndpoint(uri, this, config);
        endpoint.setType(getCamelContext().getTypeConverter().convertTo(JiraType.class, remaining));
        setProperties(endpoint, parameters);
        return endpoint;
    }

    /**
     * To use a shared base jira configuration.
     */
    public JiraConfiguration getConfiguration() {
        return configuration;
    }

    public void setConfiguration(JiraConfiguration configuration) {
        this.configuration = configuration;
    }

}
